@@ -9,7 +9,11 @@ DEFAULT_CONFIG = {
     "grpc_workers": 2,
     "sqlalchemy_uri": "sqlite:///:memory:",
     "sqlalchemy_pool_size": 3,
-    "sqlalchemy_max_overflow": 5
+    "sqlalchemy_max_overflow": 5,
+    "logging_format": "%(asctime)s - %(name)s - %(levelname)s - %(message)s",
+    "logging_directory": "/tmp/log",
+    "logging_backup_count": 5,
+    "logging_max_bytes": 102400,
 }
 
 
