@@ -250,7 +250,7 @@ class _Printer(object):
         elif field.cpp_type == descriptor.FieldDescriptor.CPPTYPE_BOOL:
             return bool(value)
         elif field.cpp_type in _INT64_TYPES:
-            return str(value)
+            return int(value)
         elif field.cpp_type in _FLOAT_TYPES:
             if math.isinf(value):
                 if value < 0.0:
